@@ -17,7 +17,6 @@ import os
 # Workaround for a OSX bug
 if os.environ.get('LC_CTYPE', '').lower() == 'utf-8':
     os.environ['LC_CTYPE'] = 'en_US.utf-8'
-
 import datetime as d
 from decimal import Decimal
 import io
@@ -27,14 +26,18 @@ import re
 
 from babel import dates, numbers, Locale
 try:
-    from jinja2 import Markup
+    from markupsafe import Markup
 except ImportError:
-    Markup = lambda x: x
+    try:
+        from jinja2 import Markup
+    except ImportError:
+        Markup = lambda x: x
 from pytz import timezone, UTC
 import yaml
 
 
-__version__ = '0.1'
+
+__version__ = '0.2'
 
 
 LOCALES_DIR = 'locales'
@@ -346,6 +349,21 @@ class I18n(object):
         return value
 
 
+    @property
+    def lazy_translate(self):
+
+        class LazyWrapper(object):
+
+            def __init__(self_, *args, **kwargs):
+                self_.args = args
+                self_.kwargs = kwargs
+
+            def __repr__(self_):
+                return self.translate(*self_.args, **self_.kwargs)
+
+        return LazyWrapper
+
+
     def pluralize(self, d, count):
         """Takes a dictionary and a number and return the value whose key in
         the dictionary is that number.  If that key doesn't exist, a `'n'` key
@@ -711,3 +729,4 @@ def get_django_ua_language(request):
         return match.group(1) or match.group(2)
     return None
 
+
